.. -*- mode: rst ; ispell-local-dictionary: "american" -*-

.. include:: _manpage-header.rst

==========================
git flow init
==========================
-------------------------------------------------------------
Initialize the repository for git flow usage
-------------------------------------------------------------


Synopsis
------------

`git flow init` [-f|--force] [-d|--defaults]


Description
------------

Setup a git repository for git flow usage. Can also be used to start a
git repository.


Options
------------

  -h, --help      Show help message and exit.
  -f, --force     Force reinitialization of the gitflow preferences.
  -d, --defaults  Use default branch naming conventions and prefixes.


.. include:: _manpage-footer.rst
